# QuantumChemPy

Este es un paquete que contiene diversas utilidades para programar y probar ideas y teorías de química cuántica.

Este paquete está en proceso de creación y aún no se encuentra en estado de producción.

## Instalación

Puede instalar este paquete con
```
pip install quantumchempy
```

## Tutoriales

Algunas pruebas se encuentra en la carpeta tests

## Autores

M. en C. Juan Felipe Huan Lew Yee
Dr. Jorge Martín del Campo Ramírez
